# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class LinkRequest(UniversalBaseModel):
    url: str = pydantic.Field()
    """
    URL to extract a downloadable link from. This link must originate from a supported site. You can use the get supported sites endpoint to get a list of supported sites.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from typing import List, Any

from soferai.core.serialization import convert_and_respect_annotation_metadata
from .assets.models import ShapeParams, ObjectWithOptionalFieldParams


UNION_TEST: ShapeParams = {"radius_measurement": 1.0, "shape_type": "circle", "id": "1"}
UNION_TEST_CONVERTED = {"shapeType": "circle", "radiusMeasurement": 1.0, "id": "1"}


def test_convert_and_respect_annotation_metadata() -> None:
    data: ObjectWithOptionalFieldParams = {
        "string": "string",
        "long_": 12345,
        "bool_": True,
        "literal": "lit_one",
        "any": "any",
    }
    converted = convert_and_respect_annotation_metadata(
        object_=data, annotation=ObjectWithOptionalFieldParams, direction="write"
    )
    assert converted == {"string": "string", "long": 12345, "bool": True, "literal": "lit_one", "any": "any"}


def test_convert_and_respect_annotation_metadata_in_list() -> None:
    data: List[ObjectWithOptionalFieldParams] = [
        {"string": "string", "long_": 12345, "bool_": True, "literal": "lit_one", "any": "any"},
        {"string": "another string", "long_": 67890, "list_": [], "literal": "lit_one", "any": "any"},
    ]
    converted = convert_and_respect_annotation_metadata(
        object_=data, annotation=List[ObjectWithOptionalFieldParams], direction="write"
    )

    assert converted == [
        {"string": "string", "long": 12345, "bool": True, "literal": "lit_one", "any": "any"},
        {"string": "another string", "long": 67890, "list": [], "literal": "lit_one", "any": "any"},
    ]


def test_convert_and_respect_annotation_metadata_in_nested_object() -> None:
    data: ObjectWithOptionalFieldParams = {
        "string": "string",
        "long_": 12345,
        "union": UNION_TEST,
        "literal": "lit_one",
        "any": "any",
    }
    converted = convert_and_respect_annotation_metadata(
        object_=data, annotation=ObjectWithOptionalFieldParams, direction="write"
    )

    assert converted == {
        "string": "string",
        "long": 12345,
        "union": UNION_TEST_CONVERTED,
        "literal": "lit_one",
        "any": "any",
    }


def test_convert_and_respect_annotation_metadata_in_union() -> None:
    converted = convert_and_respect_annotation_metadata(object_=UNION_TEST, annotation=ShapeParams, direction="write")

    assert converted == UNION_TEST_CONVERTED


def test_convert_and_respect_annotation_metadata_with_empty_object() -> None:
    data: Any = {}
    converted = convert_and_respect_annotation_metadata(object_=data, annotation=ShapeParams, direction="write")
    assert converted == data



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .transcription_id import TranscriptionId
import pydantic
import datetime as dt
from .language import Language
import typing
from .letters_language import LettersLanguage
from .status import Status


class TranscriptionInfo(UniversalBaseModel):
    id: TranscriptionId = pydantic.Field()
    """
    ID of the transcription
    """

    title: str = pydantic.Field()
    """
    Title of the transcription
    """

    created_at: dt.datetime = pydantic.Field()
    """
    When the transcription was created
    """

    primary_language: Language = pydantic.Field()
    """
    The primary language of the audio content, which can be English (en), Hebrew (he), or Yiddish (yi).
    """

    hebrew_word_format: typing.List[LettersLanguage] = pydantic.Field()
    """
    Indicates how Hebrew words are transcribed in the response when the primary language is English.
    - Hebrew words are in Hebrew letters if "he" is specified.
    - Hebrew words are transliterated into English letters if "en" is specified.
    - If both "he" and "en" are specified, both versions are provided back-to-back for each Hebrew word.
    Transliterated Hebrew words are surrounded by <i> tags in the response text.
    """

    num_speakers: int = pydantic.Field()
    """
    Number of speakers in the audio. If more than 1, then speaker labeling is enabled (a pro feature).
    """

    status: Status = pydantic.Field()
    """
    Current status of the transcription
    """

    duration: typing.Optional[float] = pydantic.Field(default=None)
    """
    Duration of the audio in seconds. If None, it means the duration was not calculated yet.
    """

    model: typing.Optional[str] = pydantic.Field(default=None)
    """
    Model used for the transcription. V1 is the latest and most accurate model, especially for audio with longer stretches of Hebrew. V0 is suitable for audio with fewer Hebrew words.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import uuid
import pydantic
import datetime as dt
import typing


class Category(UniversalBaseModel):
    id: uuid.UUID = pydantic.Field()
    """
    Unique identifier for the category
    """

    name: str = pydantic.Field()
    """
    Name of the category
    """

    color_hex: str = pydantic.Field()
    """
    Hex color code for the category
    """

    created_at: dt.datetime = pydantic.Field()
    """
    When the category was created
    """

    transcription_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of transcriptions in this category
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class RemoveKnowledgeBaseDocumentResponse(UniversalBaseModel):
    success: bool = pydantic.Field()
    """
    True if the document was successfully removed or was not present.
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional message describing the outcome (e.g., not found).
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from .confidence import Confidence
from .outline_request import OutlineRequest
from .outline_topic import OutlineTopic

__all__ = ["Confidence", "OutlineRequest", "OutlineTopic"]



# This file was auto-generated by Fern from our API Definition.

from .add_knowledge_base_document_request import AddKnowledgeBaseDocumentRequest
from .add_knowledge_base_document_response import AddKnowledgeBaseDocumentResponse
from .remove_knowledge_base_document_response import RemoveKnowledgeBaseDocumentResponse

__all__ = ["AddKnowledgeBaseDocumentRequest", "AddKnowledgeBaseDocumentResponse", "RemoveKnowledgeBaseDocumentResponse"]



# content of conftest.py


import pytest
from pytest import CallInfo, Item

# store history of failures per test class name and per index in parametrize (if parametrize used)
_test_failed_incremental: dict[str, dict[tuple[int, ...], str]] = {}


def pytest_runtest_makereport(item: Item, call: CallInfo[None]) -> None:
    if "incremental" in item.keywords and call.excinfo is not None:
        # the test has failed
        # retrieve the class name of the test
        cls_name = str(item.cls)
        # retrieve the index of the test (if parametrize is used in combination with incremental)
        parametrize_index = tuple(item.callspec.indices.values()) if hasattr(item, "callspec") else ()
        # retrieve the name of the test function
        test_name = item.originalname or item.name
        # store in _test_failed_incremental the original name of the failed test
        _test_failed_incremental.setdefault(cls_name, {}).setdefault(parametrize_index, test_name)


def pytest_runtest_setup(item: Item) -> None:
    if "incremental" in item.keywords:
        # retrieve the class name of the test
        cls_name = str(item.cls)
        # check if a previous test has failed for this class
        if cls_name in _test_failed_incremental:
            # retrieve the index of the test (if parametrize is used in combination with incremental)
            parametrize_index = tuple(item.callspec.indices.values()) if hasattr(item, "callspec") else ()
            # retrieve the name of the first test function to fail for this class name and index
            test_name = _test_failed_incremental[cls_name].get(parametrize_index, None)
            # if name found, test has failed for the combination of class name & test name
            if test_name is not None:
                pytest.xfail(f"previous test failed ({test_name})")



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .transcription_id import TranscriptionId
from .language import Language
from .letters_language import LettersLanguage


class TranscriptionRequestInfo(UniversalBaseModel):
    model: typing.Optional[str] = pydantic.Field(default=None)
    """
    Model to be used for the transcription. Default is "v1".
    - v1: Our latest and most accurate model, especially for audio with longer stretches of Hebrew.
    Priced at 1.20 USD per hour of audio transcribed.
    - v0: Not generally recommended. Cheaper, but less accurate.
    Priced at 1.00 USD per hour.
    """

    id: typing.Optional[TranscriptionId] = pydantic.Field(default=None)
    """
    ID of the transcription. If passed, it will be set as the ID. If not, a UUID will be generated.
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    Title for the transcription, Default is "Untitled"
    """

    primary_language: typing.Optional[Language] = pydantic.Field(default=None)
    """
    Specifies the primary language spoken in the audio content. Default is English.
    - en: English
    - he: Hebrew
    - yi: Yiddish
    """

    hebrew_word_format: typing.Optional[typing.List[LettersLanguage]] = pydantic.Field(default=None)
    """
    Relevant only if the primary language is English. This setting determines how non-English word, are formatted in the transcription.
    - To include Hebrew words in their original Hebrew letters, specify "he".
    - To transliterate Hebrew words into English letters, specify "en".
    - If both "he" and "en" are specified, each Hebrew word will be provided in both formats, with the transliteration in <i> tags.
    - If the primary language is English, the default is to include both English transliteration and original Hebrew letters ("en" and "he").
    - If the primary language is not English, the default and only option is to include Hebrew words in their original Hebrew letters ("he").
    """

    num_speakers: typing.Optional[int] = pydantic.Field(default=None)
    """
    Expected number of speakers in the audio. Default is 1. If a number more than 1 is passed, it will be used for speaker labeling (a pro feature).
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from .types.add_knowledge_base_document_response import AddKnowledgeBaseDocumentResponse
from ..core.pydantic_utilities import parse_obj_as
from ..transcribe.errors.authentication_error import AuthenticationError
from ..transcribe.errors.rate_limit_error import RateLimitError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from .types.remove_knowledge_base_document_response import RemoveKnowledgeBaseDocumentResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class MaishivClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def add_to_knowledge_base(
        self, *, document_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AddKnowledgeBaseDocumentResponse:
        """
        Add a document to the knowledge base.

        Parameters
        ----------
        document_id : str
            ID of the document to add to the knowledge base.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddKnowledgeBaseDocumentResponse

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.maishiv.add_to_knowledge_base(
            document_id="document_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/maishiv/knowledge-base",
            method="POST",
            json={
                "document_id": document_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddKnowledgeBaseDocumentResponse,
                    parse_obj_as(
                        type_=AddKnowledgeBaseDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def list_knowledge_base_docs(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.List[str]:
        """
        Get all document IDs currently in the knowledge base.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[str]

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.maishiv.list_knowledge_base_docs()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/maishiv/knowledge-base",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[str],
                    parse_obj_as(
                        type_=typing.List[str],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def remove_from_knowledge_base(
        self, document_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> RemoveKnowledgeBaseDocumentResponse:
        """
        Remove a document from the knowledge base.

        Parameters
        ----------
        document_id : str
            ID of the document to remove from the knowledge base.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        RemoveKnowledgeBaseDocumentResponse

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.maishiv.remove_from_knowledge_base(
            document_id="document_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/maishiv/knowledge-base/{jsonable_encoder(document_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    RemoveKnowledgeBaseDocumentResponse,
                    parse_obj_as(
                        type_=RemoveKnowledgeBaseDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncMaishivClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def add_to_knowledge_base(
        self, *, document_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AddKnowledgeBaseDocumentResponse:
        """
        Add a document to the knowledge base.

        Parameters
        ----------
        document_id : str
            ID of the document to add to the knowledge base.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddKnowledgeBaseDocumentResponse

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.maishiv.add_to_knowledge_base(
                document_id="document_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/maishiv/knowledge-base",
            method="POST",
            json={
                "document_id": document_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddKnowledgeBaseDocumentResponse,
                    parse_obj_as(
                        type_=AddKnowledgeBaseDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def list_knowledge_base_docs(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[str]:
        """
        Get all document IDs currently in the knowledge base.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[str]

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.maishiv.list_knowledge_base_docs()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/maishiv/knowledge-base",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[str],
                    parse_obj_as(
                        type_=typing.List[str],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def remove_from_knowledge_base(
        self, document_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> RemoveKnowledgeBaseDocumentResponse:
        """
        Remove a document from the knowledge base.

        Parameters
        ----------
        document_id : str
            ID of the document to remove from the knowledge base.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        RemoveKnowledgeBaseDocumentResponse

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.maishiv.remove_from_knowledge_base(
                document_id="document_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/maishiv/knowledge-base/{jsonable_encoder(document_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    RemoveKnowledgeBaseDocumentResponse,
                    parse_obj_as(
                        type_=RemoveKnowledgeBaseDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...transcribe.types.transcription_id import TranscriptionId
import pydantic
import typing


class OutlineRequest(UniversalBaseModel):
    transcription_id: TranscriptionId = pydantic.Field()
    """
    ID of the transcription to process end-to-end
    """

    monotone: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, each topic is searched after the previous topic's start (with a small backoff)
    """

    conclusion_bias: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true and a title includes the word "conclusion", search in the last third of the audio
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
import uuid
from ..core.request_options import RequestOptions
from .types.transcript_summary_response import TranscriptSummaryResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..transcribe.errors.transcription_not_found import TranscriptionNotFound
from ..transcribe.errors.authentication_error import AuthenticationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TransformationsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def generate_summary(
        self,
        transcription_id_: uuid.UUID,
        *,
        transcription_id: uuid.UUID,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TranscriptSummaryResponse:
        """
        Generate a Markdown summary for a transcription. If a summary already exists, it is returned.

        Parameters
        ----------
        transcription_id_ : uuid.UUID
            ID of the transcription to summarize

        transcription_id : uuid.UUID
            ID of the transcription to summarize

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptSummaryResponse

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.transformations.generate_summary(
            transcription_id_=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            transcription_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/transformations/{jsonable_encoder(transcription_id_)}/summary",
            method="POST",
            json={
                "transcription_id": transcription_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    TranscriptSummaryResponse,
                    parse_obj_as(
                        type_=TranscriptSummaryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise TranscriptionNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_summary(
        self, transcription_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> TranscriptSummaryResponse:
        """
        Get the Markdown summary for a transcription if it exists.

        Parameters
        ----------
        transcription_id : uuid.UUID
            ID of the transcription to fetch summary for

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptSummaryResponse

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.transformations.get_summary(
            transcription_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/transformations/{jsonable_encoder(transcription_id)}/summary",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    TranscriptSummaryResponse,
                    parse_obj_as(
                        type_=TranscriptSummaryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise TranscriptionNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncTransformationsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def generate_summary(
        self,
        transcription_id_: uuid.UUID,
        *,
        transcription_id: uuid.UUID,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TranscriptSummaryResponse:
        """
        Generate a Markdown summary for a transcription. If a summary already exists, it is returned.

        Parameters
        ----------
        transcription_id_ : uuid.UUID
            ID of the transcription to summarize

        transcription_id : uuid.UUID
            ID of the transcription to summarize

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptSummaryResponse

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transformations.generate_summary(
                transcription_id_=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                transcription_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/transformations/{jsonable_encoder(transcription_id_)}/summary",
            method="POST",
            json={
                "transcription_id": transcription_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    TranscriptSummaryResponse,
                    parse_obj_as(
                        type_=TranscriptSummaryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise TranscriptionNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_summary(
        self, transcription_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> TranscriptSummaryResponse:
        """
        Get the Markdown summary for a transcription if it exists.

        Parameters
        ----------
        transcription_id : uuid.UUID
            ID of the transcription to fetch summary for

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptSummaryResponse

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transformations.get_summary(
                transcription_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/transformations/{jsonable_encoder(transcription_id)}/summary",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    TranscriptSummaryResponse,
                    parse_obj_as(
                        type_=TranscriptSummaryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise TranscriptionNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class AudioChunk(UniversalBaseModel):
    """
    Binary chunk of PCM audio streamed from the client.
    """

    data: str = pydantic.Field()
    """
    PCM audio data chunk
    """

    mime_type: str

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from .generate_transcript_summary_request import GenerateTranscriptSummaryRequest
from .transcript_summary_response import TranscriptSummaryResponse

__all__ = ["GenerateTranscriptSummaryRequest", "TranscriptSummaryResponse"]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    AddKnowledgeBaseDocumentRequest,
    AddKnowledgeBaseDocumentResponse,
    RemoveKnowledgeBaseDocumentResponse,
)

__all__ = ["AddKnowledgeBaseDocumentRequest", "AddKnowledgeBaseDocumentResponse", "RemoveKnowledgeBaseDocumentResponse"]



# This file was auto-generated by Fern from our API Definition.

from .types import GenerateTranscriptSummaryRequest, TranscriptSummaryResponse

__all__ = ["GenerateTranscriptSummaryRequest", "TranscriptSummaryResponse"]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic


class TranscriptChunk(UniversalBaseModel):
    """
    Partial (or final) transcript text streamed from server.
    """

    text: str

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

import enum


class SoferAIEnvironment(enum.Enum):
    PRODUCTION = "https://api.sofer.ai"
    STAGING = "https://api-staging.sofer.ai"
    DEVELOPMENT = "http://localhost:8001"



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .transcription_request_info import TranscriptionRequestInfo


class TranscriptionRequest(UniversalBaseModel):
    audio_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to a downloadable audio file. Must be a direct link to the file (not a streaming or preview link). If the URL is not directly downloadable, consider using our Link API to extract a downloadable link from supported sites. Either audio_url or audio_file must be provided, but not both.
    """

    audio_file: typing.Optional[str] = pydantic.Field(default=None)
    """
    Base64 encoded audio file content. Either audio_url or audio_file must be provided, but not both.
    
    ## Base64 Encoding Example
    
    **Python:**
    ```python
    import base64
    from soferai import SoferAI
    
    # Initialize client
    client = SoferAI(api_key="your_api_key_here")
    
    # Read and encode audio file
    with open("audio.mp3", "rb") as f:
        base64_audio = base64.b64encode(f.read()).decode('utf-8')
    
    # Create transcription request
    response = client.transcribe.create_transcription(
        audio_file=base64_audio,
        info={
            "model": "v1",
            "primary_language": "en",
            "hebrew_word_format": ["he"],
            "title": "My Shiur Transcription"
        }
    )
    
    print(f"Transcription ID: {response}")
    ```
    """

    info: TranscriptionRequestInfo = pydantic.Field()
    """
    Transcription parameters
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import uuid
import pydantic
import typing
from .transcription_id import TranscriptionId
from .batch_status import BatchStatus


class BatchTranscriptionResponse(UniversalBaseModel):
    batch_id: uuid.UUID = pydantic.Field()
    """
    Unique identifier for the batch
    """

    transcription_ids: typing.List[TranscriptionId] = pydantic.Field()
    """
    List of transcription IDs that were created for this batch
    """

    total_count: int = pydantic.Field()
    """
    Total number of transcriptions in the batch
    """

    status: BatchStatus = pydantic.Field()
    """
    Current status of the batch
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .timestamp import Timestamp
import pydantic
from .language import Language


class UpdateTimestampsRequest(UniversalBaseModel):
    old_timestamps: typing.List[Timestamp] = pydantic.Field()
    """
    The original timestamps associated with the text before editing. These will be used as reference points to align the new timestamps.
    """

    edited_text: str = pydantic.Field()
    """
    The modified version of the transcription text that needs updated timestamp alignments. This should be the complete text after your edits.
    """

    language_to_update: Language = pydantic.Field()
    """
    Specifies which language version of the timestamps to update. Must be either 'en' for English or 'he' for Hebrew timestamps.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.api_error import ApiError


class AuthenticationError(ApiError):
    def __init__(self) -> None:
        super().__init__(status_code=401)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .transcription_id import TranscriptionId
import pydantic
from .status import Status
import typing


class TranscriptionSummary(UniversalBaseModel):
    id: TranscriptionId = pydantic.Field()
    """
    ID of the transcription
    """

    title: str = pydantic.Field()
    """
    Title of the transcription
    """

    status: Status = pydantic.Field()
    """
    Current status of the transcription
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from .duration_request import DurationRequest
from .duration_response import DurationResponse

__all__ = ["DurationRequest", "DurationResponse"]



# This file was auto-generated by Fern from our API Definition.

# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class ObjectWithDefaultsParams(typing_extensions.TypedDict):
    """
    Defines properties with default values and validation rules.
    """

    decimal: typing_extensions.NotRequired[float]
    string: typing_extensions.NotRequired[str]
    required_string: str



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from .types.transcription_request_info import TranscriptionRequestInfo
from ..core.request_options import RequestOptions
from .types.transcription_id import TranscriptionId
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.pydantic_utilities import parse_obj_as
from .errors.authentication_error import AuthenticationError
from .errors.rate_limit_error import RateLimitError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from .types.audio_source import AudioSource
import uuid
from .types.batch_transcription_response import BatchTranscriptionResponse
from .types.batch_status_response import BatchStatusResponse
from ..core.jsonable_encoder import jsonable_encoder
from .errors.batch_not_found import BatchNotFound
from .types.transcription_info import TranscriptionInfo
from .errors.transcription_not_found import TranscriptionNotFound
from .types.transcription import Transcription
from .types.transcription_summary import TranscriptionSummary
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TranscribeClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_transcription(
        self,
        *,
        info: TranscriptionRequestInfo,
        audio_url: typing.Optional[str] = OMIT,
        audio_file: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TranscriptionId:
        """
        Create a new transcription

        Parameters
        ----------
        info : TranscriptionRequestInfo
            Transcription parameters

        audio_url : typing.Optional[str]
            URL to a downloadable audio file. Must be a direct link to the file (not a streaming or preview link). If the URL is not directly downloadable, consider using our Link API to extract a downloadable link from supported sites. Either audio_url or audio_file must be provided, but not both.

        audio_file : typing.Optional[str]
            Base64 encoded audio file content. Either audio_url or audio_file must be provided, but not both.

            ## Base64 Encoding Example

            **Python:**
            ```python
            import base64
            from soferai import SoferAI

            # Initialize client
            client = SoferAI(api_key="your_api_key_here")

            # Read and encode audio file
            with open("audio.mp3", "rb") as f:
                base64_audio = base64.b64encode(f.read()).decode("utf-8")

            # Create transcription request
            response = client.transcribe.create_transcription(
                audio_file=base64_audio,
                info={
                    "model": "v1",
                    "primary_language": "en",
                    "hebrew_word_format": ["he"],
                    "title": "My Shiur Transcription",
                },
            )

            print(f"Transcription ID: {response}")
            ```

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptionId
            The unique identifier for the newly created transcription.
            Use this ID to check the status of the transcription or to retrieve the transcription result.

        Examples
        --------
        from soferai import SoferAI
        from soferai.transcribe import TranscriptionRequestInfo

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.transcribe.create_transcription(
            info=TranscriptionRequestInfo(),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/transcriptions/",
            method="POST",
            json={
                "audio_url": audio_url,
                "audio_file": audio_file,
                "info": convert_and_respect_annotation_metadata(
                    object_=info, annotation=TranscriptionRequestInfo, direction="write"
                ),
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    TranscriptionId,
                    parse_obj_as(
                        type_=TranscriptionId,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_batch_transcription(
        self,
        *,
        audio_sources: typing.Sequence[AudioSource],
        info: TranscriptionRequestInfo,
        batch_title: typing.Optional[str] = OMIT,
        batch_id: typing.Optional[uuid.UUID] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> BatchTranscriptionResponse:
        """
        Create multiple transcriptions to be processed in batch

        Parameters
        ----------
        audio_sources : typing.Sequence[AudioSource]
            List of audio sources to transcribe with the same settings. Each item should have either audio_url or audio_file.

        info : TranscriptionRequestInfo
            Shared transcription parameters for all audio files in the batch

        batch_title : typing.Optional[str]
            Optional title for the batch. The system will first check for a title in the Audio Source itself. If no title is provided there, it defaults to batch title providded here with "- Batch Item N" appended.

        batch_id : typing.Optional[uuid.UUID]
            Optional ID for the batch. If not provided, a UUID will be generated.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        BatchTranscriptionResponse
            Information about the created batch including batch ID and individual transcription IDs.
            All transcriptions will be processed sequentially with delays between them.

        Examples
        --------
        from soferai import SoferAI
        from soferai.transcribe import AudioSource, TranscriptionRequestInfo

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.transcribe.create_batch_transcription(
            audio_sources=[AudioSource(), AudioSource()],
            info=TranscriptionRequestInfo(),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/transcriptions/batch",
            method="POST",
            json={
                "audio_sources": convert_and_respect_annotation_metadata(
                    object_=audio_sources, annotation=typing.Sequence[AudioSource], direction="write"
                ),
                "info": convert_and_respect_annotation_metadata(
                    object_=info, annotation=TranscriptionRequestInfo, direction="write"
                ),
                "batch_title": batch_title,
                "batch_id": batch_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    BatchTranscriptionResponse,
                    parse_obj_as(
                        type_=BatchTranscriptionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_batch_status(
        self, batch_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> BatchStatusResponse:
        """
        Get status of a batch transcription

        Parameters
        ----------
        batch_id : uuid.UUID
            ID of the batch. Use the ID returned from the Create Batch Transcription endpoint.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        BatchStatusResponse

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.transcribe.get_batch_status(
            batch_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/transcriptions/batch/{jsonable_encoder(batch_id)}/status",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    BatchStatusResponse,
                    parse_obj_as(
                        type_=BatchStatusResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise BatchNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_transcription_status(
        self, transcription_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> TranscriptionInfo:
        """
        Get transcription status

        Parameters
        ----------
        transcription_id : uuid.UUID
            ID of the transcription. Use the ID returned from the Create Transcription endpoint.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptionInfo

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.transcribe.get_transcription_status(
            transcription_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/transcriptions/{jsonable_encoder(transcription_id)}/status",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    TranscriptionInfo,
                    parse_obj_as(
                        type_=TranscriptionInfo,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise TranscriptionNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_transcription(
        self,
        transcription_id: uuid.UUID,
        *,
        filter_hebrew_word_format: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Transcription:
        """
        Get transcription

        Parameters
        ----------
        transcription_id : uuid.UUID
            ID of the transcription. Use the ID returned from the Create Transcription endpoint.

        filter_hebrew_word_format : typing.Optional[str]
            Optionally filter the response to a single Hebrew word format. If set to "en", the response text will have Hebrew characters removed and timestamps will exclude words tagged with "he". If set to "he", italicized transliterations are removed from the text and timestamps will exclude words tagged only with "en".

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Transcription

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.transcribe.get_transcription(
            transcription_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/transcriptions/{jsonable_encoder(transcription_id)}",
            method="GET",
            params={
                "filter_hebrew_word_format": filter_hebrew_word_format,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Transcription,
                    parse_obj_as(
                        type_=Transcription,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise TranscriptionNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def list_transcriptions(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[TranscriptionSummary]:
        """
        Get all transcriptions for the authenticated user

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[TranscriptionSummary]

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.transcribe.list_transcriptions()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/transcriptions/",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[TranscriptionSummary],
                    parse_obj_as(
                        type_=typing.List[TranscriptionSummary],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncTranscribeClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_transcription(
        self,
        *,
        info: TranscriptionRequestInfo,
        audio_url: typing.Optional[str] = OMIT,
        audio_file: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TranscriptionId:
        """
        Create a new transcription

        Parameters
        ----------
        info : TranscriptionRequestInfo
            Transcription parameters

        audio_url : typing.Optional[str]
            URL to a downloadable audio file. Must be a direct link to the file (not a streaming or preview link). If the URL is not directly downloadable, consider using our Link API to extract a downloadable link from supported sites. Either audio_url or audio_file must be provided, but not both.

        audio_file : typing.Optional[str]
            Base64 encoded audio file content. Either audio_url or audio_file must be provided, but not both.

            ## Base64 Encoding Example

            **Python:**
            ```python
            import base64
            from soferai import SoferAI

            # Initialize client
            client = SoferAI(api_key="your_api_key_here")

            # Read and encode audio file
            with open("audio.mp3", "rb") as f:
                base64_audio = base64.b64encode(f.read()).decode("utf-8")

            # Create transcription request
            response = client.transcribe.create_transcription(
                audio_file=base64_audio,
                info={
                    "model": "v1",
                    "primary_language": "en",
                    "hebrew_word_format": ["he"],
                    "title": "My Shiur Transcription",
                },
            )

            print(f"Transcription ID: {response}")
            ```

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptionId
            The unique identifier for the newly created transcription.
            Use this ID to check the status of the transcription or to retrieve the transcription result.

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI
        from soferai.transcribe import TranscriptionRequestInfo

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcribe.create_transcription(
                info=TranscriptionRequestInfo(),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/transcriptions/",
            method="POST",
            json={
                "audio_url": audio_url,
                "audio_file": audio_file,
                "info": convert_and_respect_annotation_metadata(
                    object_=info, annotation=TranscriptionRequestInfo, direction="write"
                ),
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    TranscriptionId,
                    parse_obj_as(
                        type_=TranscriptionId,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_batch_transcription(
        self,
        *,
        audio_sources: typing.Sequence[AudioSource],
        info: TranscriptionRequestInfo,
        batch_title: typing.Optional[str] = OMIT,
        batch_id: typing.Optional[uuid.UUID] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> BatchTranscriptionResponse:
        """
        Create multiple transcriptions to be processed in batch

        Parameters
        ----------
        audio_sources : typing.Sequence[AudioSource]
            List of audio sources to transcribe with the same settings. Each item should have either audio_url or audio_file.

        info : TranscriptionRequestInfo
            Shared transcription parameters for all audio files in the batch

        batch_title : typing.Optional[str]
            Optional title for the batch. The system will first check for a title in the Audio Source itself. If no title is provided there, it defaults to batch title providded here with "- Batch Item N" appended.

        batch_id : typing.Optional[uuid.UUID]
            Optional ID for the batch. If not provided, a UUID will be generated.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        BatchTranscriptionResponse
            Information about the created batch including batch ID and individual transcription IDs.
            All transcriptions will be processed sequentially with delays between them.

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI
        from soferai.transcribe import AudioSource, TranscriptionRequestInfo

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcribe.create_batch_transcription(
                audio_sources=[AudioSource(), AudioSource()],
                info=TranscriptionRequestInfo(),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/transcriptions/batch",
            method="POST",
            json={
                "audio_sources": convert_and_respect_annotation_metadata(
                    object_=audio_sources, annotation=typing.Sequence[AudioSource], direction="write"
                ),
                "info": convert_and_respect_annotation_metadata(
                    object_=info, annotation=TranscriptionRequestInfo, direction="write"
                ),
                "batch_title": batch_title,
                "batch_id": batch_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    BatchTranscriptionResponse,
                    parse_obj_as(
                        type_=BatchTranscriptionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_batch_status(
        self, batch_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> BatchStatusResponse:
        """
        Get status of a batch transcription

        Parameters
        ----------
        batch_id : uuid.UUID
            ID of the batch. Use the ID returned from the Create Batch Transcription endpoint.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        BatchStatusResponse

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcribe.get_batch_status(
                batch_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/transcriptions/batch/{jsonable_encoder(batch_id)}/status",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    BatchStatusResponse,
                    parse_obj_as(
                        type_=BatchStatusResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise BatchNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_transcription_status(
        self, transcription_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> TranscriptionInfo:
        """
        Get transcription status

        Parameters
        ----------
        transcription_id : uuid.UUID
            ID of the transcription. Use the ID returned from the Create Transcription endpoint.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptionInfo

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcribe.get_transcription_status(
                transcription_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/transcriptions/{jsonable_encoder(transcription_id)}/status",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    TranscriptionInfo,
                    parse_obj_as(
                        type_=TranscriptionInfo,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise TranscriptionNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_transcription(
        self,
        transcription_id: uuid.UUID,
        *,
        filter_hebrew_word_format: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Transcription:
        """
        Get transcription

        Parameters
        ----------
        transcription_id : uuid.UUID
            ID of the transcription. Use the ID returned from the Create Transcription endpoint.

        filter_hebrew_word_format : typing.Optional[str]
            Optionally filter the response to a single Hebrew word format. If set to "en", the response text will have Hebrew characters removed and timestamps will exclude words tagged with "he". If set to "he", italicized transliterations are removed from the text and timestamps will exclude words tagged only with "en".

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Transcription

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcribe.get_transcription(
                transcription_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/transcriptions/{jsonable_encoder(transcription_id)}",
            method="GET",
            params={
                "filter_hebrew_word_format": filter_hebrew_word_format,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Transcription,
                    parse_obj_as(
                        type_=Transcription,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise TranscriptionNotFound()
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def list_transcriptions(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[TranscriptionSummary]:
        """
        Get all transcriptions for the authenticated user

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[TranscriptionSummary]

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcribe.list_transcriptions()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/transcriptions/",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[TranscriptionSummary],
                    parse_obj_as(
                        type_=typing.List[TranscriptionSummary],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from .link_request import LinkRequest
from .link_response import LinkResponse
from .site import Site

__all__ = ["LinkRequest", "LinkResponse", "Site"]



# This file was auto-generated by Fern from our API Definition.

import typing
from .environment import SoferAIEnvironment
import os
import httpx
from .core.client_wrapper import SyncClientWrapper
from .balance.client import BalanceClient
from .categories.client import CategoriesClient
from .health.client import HealthClient
from .link.client import LinkClient
from .maishiv.client import MaishivClient
from .timestamps.client import TimestampsClient
from .transcribe.client import TranscribeClient
from .transformations.client import TransformationsClient
from .utils.client import UtilsClient
from .core.client_wrapper import AsyncClientWrapper
from .balance.client import AsyncBalanceClient
from .categories.client import AsyncCategoriesClient
from .health.client import AsyncHealthClient
from .link.client import AsyncLinkClient
from .maishiv.client import AsyncMaishivClient
from .timestamps.client import AsyncTimestampsClient
from .transcribe.client import AsyncTranscribeClient
from .transformations.client import AsyncTransformationsClient
from .utils.client import AsyncUtilsClient


class SoferAI:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SoferAIEnvironment
        The environment to use for requests from the client. from .environment import SoferAIEnvironment



        Defaults to SoferAIEnvironment.PRODUCTION



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from soferai import SoferAI

    client = SoferAI(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SoferAIEnvironment = SoferAIEnvironment.PRODUCTION,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SOFERAI_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.balance = BalanceClient(client_wrapper=self._client_wrapper)
        self.categories = CategoriesClient(client_wrapper=self._client_wrapper)
        self.health = HealthClient(client_wrapper=self._client_wrapper)
        self.link = LinkClient(client_wrapper=self._client_wrapper)
        self.maishiv = MaishivClient(client_wrapper=self._client_wrapper)
        self.timestamps = TimestampsClient(client_wrapper=self._client_wrapper)
        self.transcribe = TranscribeClient(client_wrapper=self._client_wrapper)
        self.transformations = TransformationsClient(client_wrapper=self._client_wrapper)
        self.utils = UtilsClient(client_wrapper=self._client_wrapper)


class AsyncSoferAI:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SoferAIEnvironment
        The environment to use for requests from the client. from .environment import SoferAIEnvironment



        Defaults to SoferAIEnvironment.PRODUCTION



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from soferai import AsyncSoferAI

    client = AsyncSoferAI(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SoferAIEnvironment = SoferAIEnvironment.PRODUCTION,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SOFERAI_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.balance = AsyncBalanceClient(client_wrapper=self._client_wrapper)
        self.categories = AsyncCategoriesClient(client_wrapper=self._client_wrapper)
        self.health = AsyncHealthClient(client_wrapper=self._client_wrapper)
        self.link = AsyncLinkClient(client_wrapper=self._client_wrapper)
        self.maishiv = AsyncMaishivClient(client_wrapper=self._client_wrapper)
        self.timestamps = AsyncTimestampsClient(client_wrapper=self._client_wrapper)
        self.transcribe = AsyncTranscribeClient(client_wrapper=self._client_wrapper)
        self.transformations = AsyncTransformationsClient(client_wrapper=self._client_wrapper)
        self.utils = AsyncUtilsClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: SoferAIEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class LinkResponse(UniversalBaseModel):
    title: str = pydantic.Field()
    """
    Title of the file
    """

    download_url: str = pydantic.Field()
    """
    Download URL of the file
    """

    file_format: str = pydantic.Field()
    """
    Format of the file
    """

    file_name: str = pydantic.Field()
    """
    Name of the file
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
import typing_extensions
import typing_extensions
import typing
from soferai.core.serialization import FieldMetadata


class Base(typing_extensions.TypedDict):
    id: str


class Shape_CircleParams(Base):
    shape_type: typing_extensions.Annotated[typing.Literal["circle"], FieldMetadata(alias="shapeType")]
    radius_measurement: typing_extensions.Annotated[float, FieldMetadata(alias="radiusMeasurement")]


class Shape_SquareParams(Base):
    shape_type: typing_extensions.Annotated[typing.Literal["square"], FieldMetadata(alias="shapeType")]
    length_measurement: typing_extensions.Annotated[float, FieldMetadata(alias="lengthMeasurement")]


ShapeParams = typing.Union[Shape_CircleParams, Shape_SquareParams]



# This file was auto-generated by Fern from our API Definition.

from .add_transcription_to_category_request import AddTranscriptionToCategoryRequest
from .add_transcription_to_category_response import AddTranscriptionToCategoryResponse
from .category import Category
from .category_transcription import CategoryTranscription
from .create_category_request import CreateCategoryRequest
from .delete_category_response import DeleteCategoryResponse
from .remove_transcription_from_category_response import RemoveTranscriptionFromCategoryResponse
from .update_category_request import UpdateCategoryRequest

__all__ = [
    "AddTranscriptionToCategoryRequest",
    "AddTranscriptionToCategoryResponse",
    "Category",
    "CategoryTranscription",
    "CreateCategoryRequest",
    "DeleteCategoryResponse",
    "RemoveTranscriptionFromCategoryResponse",
    "UpdateCategoryRequest",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from .types.link_response import LinkResponse
from ..core.pydantic_utilities import parse_obj_as
from .errors.link_not_supported import LinkNotSupported
from .errors.link_not_found import LinkNotFound
from .errors.link_error import LinkError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from .types.site import Site
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class LinkClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def extract(self, *, url: str, request_options: typing.Optional[RequestOptions] = None) -> LinkResponse:
        """
        Parameters
        ----------
        url : str
            URL to extract a downloadable link from. This link must originate from a supported site. You can use the get supported sites endpoint to get a list of supported sites.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        LinkResponse

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.link.extract(
            url="url",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/link/extract",
            method="POST",
            json={
                "url": url,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    LinkResponse,
                    parse_obj_as(
                        type_=LinkResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise LinkNotSupported()
            if _response.status_code == 404:
                raise LinkNotFound()
            if _response.status_code == 500:
                raise LinkError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_supported_sites(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.List[Site]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Site]

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.link.get_supported_sites()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/link/sites",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[Site],
                    parse_obj_as(
                        type_=typing.List[Site],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncLinkClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def extract(self, *, url: str, request_options: typing.Optional[RequestOptions] = None) -> LinkResponse:
        """
        Parameters
        ----------
        url : str
            URL to extract a downloadable link from. This link must originate from a supported site. You can use the get supported sites endpoint to get a list of supported sites.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        LinkResponse

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.link.extract(
                url="url",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/link/extract",
            method="POST",
            json={
                "url": url,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    LinkResponse,
                    parse_obj_as(
                        type_=LinkResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise LinkNotSupported()
            if _response.status_code == 404:
                raise LinkNotFound()
            if _response.status_code == 500:
                raise LinkError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_supported_sites(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[Site]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Site]

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.link.get_supported_sites()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/link/sites",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[Site],
                    parse_obj_as(
                        type_=typing.List[Site],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



import os
import time
import uuid
from datetime import datetime

import pytest

from soferai import SoferAI, SoferAIEnvironment
from soferai.health.types.health_response import HealthResponse
from soferai.link.types.link_response import LinkResponse
from soferai.transcribe.types.transcription import Transcription
from soferai.transcribe.types.transcription_id import TranscriptionId
from soferai.transcribe.types.transcription_info import TranscriptionInfo
from soferai.transcribe.types.transcription_request_info import (
    TranscriptionRequestInfo,
)


@pytest.mark.incremental
@pytest.mark.skipif(
    condition=os.getenv("SOFERAI_API_KEY") is None,
    reason="This is a test for the production environment, and requires a valid API key",
)
@pytest.mark.skipif(
    condition=os.getenv("SKIP_CLIENT_TESTS") == "true",
    reason="Skipping client tests in CI",
)
class TestSoferAIProd:
    TEST_UUID: uuid.UUID = uuid.uuid4()  # this is overwritten in a test

    # Make sure your API key is set in the environment variable SOFERAI_API_KEY
    client: SoferAI = SoferAI(environment=SoferAIEnvironment.PRODUCTION)

    def test_health(self) -> None:
        # this just tests that the api is up and taking requests
        response: HealthResponse = self.client.health.get_health()
        assert response.status == "ok"

    def test_link_extract(self) -> None:
        # this is the API frontend for `torah-dl`
        response: LinkResponse = self.client.link.extract(
            url="https://www.yutorah.org/lectures/1116616/Praying-for-Rain-and-the-International-Traveler"
        )
        assert (
            response.download_url
            == "https://download.yutorah.org/2024/986/1116616/praying-for-rain-and-the-international-traveler.mp3"
        )
        assert response.file_format == "audio/mp3"
        assert response.file_name == "praying-for-rain-and-the-international-traveler.mp3"
        assert response.title == "Praying for Rain and the International Traveler"

    def test_transcription_simple(self) -> None:
        # this is a simple runthrough of the transcription API, with no fancy features
        transcription_id: TranscriptionId = self.client.transcribe.create_transcription(
            audio_url="https://drive.google.com/uc?export=download&id=1_hSFDw_8Ps8uSMfmR9wgo8Xx92gJj_RA",
            info=TranscriptionRequestInfo(),
        )
        assert transcription_id is not None

        # wait for the transcription to complete
        for _ in range(60):
            status_response: TranscriptionInfo = self.client.transcribe.get_transcription_status(
                transcription_id=transcription_id
            )

            assert status_response.status in [
                "RECEIVED",
                "PENDING",
                "PROCESSING",
                "COMPLETED",
            ]
            if status_response.status == "COMPLETED":
                break
            time.sleep(2)
        else:
            raise AssertionError("Transcription did not complete within 60 seconds")

        # get the transcription
        response: Transcription = self.client.transcribe.get_transcription(
            transcription_id=transcription_id,
        )
        assert response.info.status == "COMPLETED"
        assert response.text is not None

    def test_create_transcription(self) -> None:
        # this is the same as the simple transcription test, but with a custom info object
        info: TranscriptionRequestInfo = TranscriptionRequestInfo(
            id=self.TEST_UUID,
            title=f"test_prod_{datetime.now().strftime('%Y%m%d%H%M%S')}",
            primary_language="en",
            hebrew_word_format=[
                "en",
                "he",
            ],
            num_speakers=1,
        )
        response: TranscriptionId = self.client.transcribe.create_transcription(
            audio_url="https://drive.google.com/uc?export=download&id=1_hSFDw_8Ps8uSMfmR9wgo8Xx92gJj_RA", info=info
        )

        assert response is not None
        assert response != ""
        assert isinstance(response, uuid.UUID)
        assert response == self.TEST_UUID

    def test_get_transcription_status(self) -> None:
        for _ in range(60):
            response: TranscriptionInfo = self.client.transcribe.get_transcription_status(
                transcription_id=self.TEST_UUID
            )

            assert response.status in [
                "RECEIVED",
                "PENDING",
                "PROCESSING",
                "COMPLETED",
            ]
            if response.status == "COMPLETED":
                return
            time.sleep(1)
        else:
            raise AssertionError("Transcription did not complete within 60 seconds")

    def test_get_transcription_complex(self) -> None:
        response: Transcription = self.client.transcribe.get_transcription(
            transcription_id=self.TEST_UUID,
        )
        assert response.info.status == "COMPLETED"
        assert response.text is not None



# This file was auto-generated by Fern from our API Definition.

from .link_error import LinkError
from .link_not_found import LinkNotFound
from .link_not_supported import LinkNotSupported

__all__ = ["LinkError", "LinkNotFound", "LinkNotSupported"]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic


class UpdateCategoryRequest(UniversalBaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    New name for the category
    """

    color_hex: typing.Optional[str] = pydantic.Field(default=None)
    """
    New hex color code for the category (e.g.,
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .timestamp import Timestamp
from .transcription_info import TranscriptionInfo


class Transcription(UniversalBaseModel):
    text: str = pydantic.Field()
    """
    This field contains the transcription text. If the `primary_language` is English and only one `hebrew_word_format` is specified, the text will be in English with Hebrew words in the specified format. If multiple `hebrew_word_format` options are set, Hebrew words will appear in both formats, with the English transliteration in <i>Italics</i>. If the primary language is Hebrew, the text will be in Hebrew.
    """

    timestamps: typing.Optional[typing.List[Timestamp]] = pydantic.Field(default=None)
    """
    Timestamps object for the transcription. See the `timestamps` object for more details.
    """

    info: TranscriptionInfo = pydantic.Field()
    """
    Additional information about the transcription
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
import typing
from ..core.request_options import RequestOptions
from .types.balance import Balance
from ..core.pydantic_utilities import parse_obj_as
from .errors.user_not_found import UserNotFound
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper


class BalanceClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_balance(self, *, request_options: typing.Optional[RequestOptions] = None) -> Balance:
        """
        Get account balance showing available balance and pending charges

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Balance

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.balance.get_balance()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/balance/",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Balance,
                    parse_obj_as(
                        type_=Balance,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise UserNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncBalanceClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_balance(self, *, request_options: typing.Optional[RequestOptions] = None) -> Balance:
        """
        Get account balance showing available balance and pending charges

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Balance

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.balance.get_balance()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/balance/",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Balance,
                    parse_obj_as(
                        type_=Balance,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise UserNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic


class DurationRequest(UniversalBaseModel):
    audio_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Direct URL to a downloadable audio file.
    """

    audio_file: typing.Optional[str] = pydantic.Field(default=None)
    """
    Base64-encoded audio file content. Do not include a data URI prefix.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .letters_language import LettersLanguage


class Timestamp(UniversalBaseModel):
    word: str = pydantic.Field()
    """
    Word
    """

    hebrew_word_format: typing.Optional[typing.List[LettersLanguage]] = pydantic.Field(default=None)
    """
    Specifies the format of Hebrew words in the transcription. Hebrew words are denoted as "he" for Hebrew letters or "en" for English transliteration. Non-Hebrew words are represented by null.
    """

    start: float = pydantic.Field()
    """
    Start time of the timestamp
    """

    end: float = pydantic.Field()
    """
    End time of the timestamp
    """

    speaker: typing.Optional[str] = pydantic.Field(default=None)
    """
    If speaker labeling was requested, indicates which speaker number spoke this word (Pro feature)
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from .audio_source import AudioSource
from .batch_status import BatchStatus
from .batch_status_response import BatchStatusResponse
from .batch_transcription_request import BatchTranscriptionRequest
from .batch_transcription_response import BatchTranscriptionResponse
from .language import Language
from .letters_language import LettersLanguage
from .status import Status
from .timestamp import Timestamp
from .transcription import Transcription
from .transcription_id import TranscriptionId
from .transcription_info import TranscriptionInfo
from .transcription_request import TranscriptionRequest
from .transcription_request_info import TranscriptionRequestInfo
from .transcription_summary import TranscriptionSummary
from .update_timestamps_request import UpdateTimestampsRequest

__all__ = [
    "AudioSource",
    "BatchStatus",
    "BatchStatusResponse",
    "BatchTranscriptionRequest",
    "BatchTranscriptionResponse",
    "Language",
    "LettersLanguage",
    "Status",
    "Timestamp",
    "Transcription",
    "TranscriptionId",
    "TranscriptionInfo",
    "TranscriptionRequest",
    "TranscriptionRequestInfo",
    "TranscriptionSummary",
    "UpdateTimestampsRequest",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import uuid
import typing


class AddTranscriptionToCategoryResponse(UniversalBaseModel):
    message: str = pydantic.Field()
    """
    Success message
    """

    category_id: uuid.UUID = pydantic.Field()
    """
    ID of the category
    """

    transcription_id: uuid.UUID = pydantic.Field()
    """
    ID of the transcription
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from soferai.core.http_client import get_request_body
from soferai.core.request_options import RequestOptions


def get_request_options() -> RequestOptions:
    return {"additional_body_parameters": {"see you": "later"}}


def test_get_json_request_body() -> None:
    json_body, data_body = get_request_body(json={"hello": "world"}, data=None, request_options=None, omit=None)
    assert json_body == {"hello": "world"}
    assert data_body is None

    json_body_extras, data_body_extras = get_request_body(
        json={"goodbye": "world"}, data=None, request_options=get_request_options(), omit=None
    )

    assert json_body_extras == {"goodbye": "world", "see you": "later"}
    assert data_body_extras is None


def test_get_files_request_body() -> None:
    json_body, data_body = get_request_body(json=None, data={"hello": "world"}, request_options=None, omit=None)
    assert data_body == {"hello": "world"}
    assert json_body is None

    json_body_extras, data_body_extras = get_request_body(
        json=None, data={"goodbye": "world"}, request_options=get_request_options(), omit=None
    )

    assert data_body_extras == {"goodbye": "world", "see you": "later"}
    assert json_body_extras is None


def test_get_none_request_body() -> None:
    json_body, data_body = get_request_body(json=None, data=None, request_options=None, omit=None)
    assert data_body is None
    assert json_body is None

    json_body_extras, data_body_extras = get_request_body(
        json=None, data=None, request_options=get_request_options(), omit=None
    )

    assert json_body_extras == {"see you": "later"}
    assert data_body_extras is None


def test_get_empty_json_request_body() -> None:
    unrelated_request_options: RequestOptions = {"max_retries": 3}
    json_body, data_body = get_request_body(json=None, data=None, request_options=unrelated_request_options, omit=None)
    assert json_body is None
    assert data_body is None

    json_body_extras, data_body_extras = get_request_body(
        json={}, data=None, request_options=unrelated_request_options, omit=None
    )

    assert json_body_extras is None
    assert data_body_extras is None



# This file was auto-generated by Fern from our API Definition.

from . import (
    balance,
    categories,
    health,
    link,
    live_transcription_ws,
    maishiv,
    timestamps,
    transcribe,
    transformations,
    utils,
)
from .balance import Balance, UserNotFound
from .categories import (
    AddTranscriptionToCategoryRequest,
    AddTranscriptionToCategoryResponse,
    Category,
    CategoryAlreadyExists,
    CategoryNotFound,
    CategoryTranscription,
    CreateCategoryRequest,
    DeleteCategoryResponse,
    RemoveTranscriptionFromCategoryResponse,
    UpdateCategoryRequest,
)
from .client import AsyncSoferAI, SoferAI
from .environment import SoferAIEnvironment
from .health import HealthResponse
from .link import LinkError, LinkNotFound, LinkNotSupported, LinkRequest, LinkResponse, Site
from .live_transcription_ws import AudioChunk, TranscriptChunk
from .maishiv import (
    AddKnowledgeBaseDocumentRequest,
    AddKnowledgeBaseDocumentResponse,
    RemoveKnowledgeBaseDocumentResponse,
)
from .timestamps import Confidence, OutlineRequest, OutlineTopic
from .transcribe import (
    AudioSource,
    AuthenticationError,
    BatchNotFound,
    BatchStatus,
    BatchStatusResponse,
    BatchTranscriptionRequest,
    BatchTranscriptionResponse,
    Language,
    LettersLanguage,
    RateLimitError,
    Status,
    Timestamp,
    Transcription,
    TranscriptionFailed,
    TranscriptionId,
    TranscriptionInfo,
    TranscriptionNotFound,
    TranscriptionRequest,
    TranscriptionRequestInfo,
    TranscriptionSummary,
    UpdateTimestampsRequest,
)
from .transformations import GenerateTranscriptSummaryRequest, TranscriptSummaryResponse
from .utils import DurationRequest, DurationResponse
from .version import __version__

__all__ = [
    "AddKnowledgeBaseDocumentRequest",
    "AddKnowledgeBaseDocumentResponse",
    "AddTranscriptionToCategoryRequest",
    "AddTranscriptionToCategoryResponse",
    "AsyncSoferAI",
    "AudioChunk",
    "AudioSource",
    "AuthenticationError",
    "Balance",
    "BatchNotFound",
    "BatchStatus",
    "BatchStatusResponse",
    "BatchTranscriptionRequest",
    "BatchTranscriptionResponse",
    "Category",
    "CategoryAlreadyExists",
    "CategoryNotFound",
    "CategoryTranscription",
    "Confidence",
    "CreateCategoryRequest",
    "DeleteCategoryResponse",
    "DurationRequest",
    "DurationResponse",
    "GenerateTranscriptSummaryRequest",
    "HealthResponse",
    "Language",
    "LettersLanguage",
    "LinkError",
    "LinkNotFound",
    "LinkNotSupported",
    "LinkRequest",
    "LinkResponse",
    "OutlineRequest",
    "OutlineTopic",
    "RateLimitError",
    "RemoveKnowledgeBaseDocumentResponse",
    "RemoveTranscriptionFromCategoryResponse",
    "Site",
    "SoferAI",
    "SoferAIEnvironment",
    "Status",
    "Timestamp",
    "TranscriptChunk",
    "TranscriptSummaryResponse",
    "Transcription",
    "TranscriptionFailed",
    "TranscriptionId",
    "TranscriptionInfo",
    "TranscriptionNotFound",
    "TranscriptionRequest",
    "TranscriptionRequestInfo",
    "TranscriptionSummary",
    "UpdateCategoryRequest",
    "UpdateTimestampsRequest",
    "UserNotFound",
    "__version__",
    "balance",
    "categories",
    "health",
    "link",
    "live_transcription_ws",
    "maishiv",
    "timestamps",
    "transcribe",
    "transformations",
    "utils",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .confidence import Confidence


class OutlineTopic(UniversalBaseModel):
    title: str = pydantic.Field()
    """
    Title of the topic
    """

    starting_phrase: str = pydantic.Field()
    """
    Starting phrase that was searched for
    """

    start_time_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    Start time in seconds for the best-aligned phrase (if found)
    """

    matched_text: str = pydantic.Field()
    """
    The transcript text segment best matching the starting phrase
    """

    score_norm: float = pydantic.Field()
    """
    Normalized alignment score in [0,1]
    """

    confidence: Confidence = pydantic.Field()
    """
    Confidence bucket derived from the normalized score
    """

    token_span: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    Optional span of token indices [start, end) for the best match
    """

    matched_content: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of matched content tokens (excludes stopwords/fillers)
    """

    content_coverage: typing.Optional[float] = pydantic.Field(default=None)
    """
    Fraction of content tokens in the phrase that were matched
    """

    longest_content_run_soft: typing.Optional[int] = pydantic.Field(default=None)
    """
    Longest soft contiguous run of content-token matches
    """

    longest_content_run_strict: typing.Optional[int] = pydantic.Field(default=None)
    """
    Longest strict contiguous run of content-token matches
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from .types import (
    AudioSource,
    BatchStatus,
    BatchStatusResponse,
    BatchTranscriptionRequest,
    BatchTranscriptionResponse,
    Language,
    LettersLanguage,
    Status,
    Timestamp,
    Transcription,
    TranscriptionId,
    TranscriptionInfo,
    TranscriptionRequest,
    TranscriptionRequestInfo,
    TranscriptionSummary,
    UpdateTimestampsRequest,
)
from .errors import AuthenticationError, BatchNotFound, RateLimitError, TranscriptionFailed, TranscriptionNotFound

__all__ = [
    "AudioSource",
    "AuthenticationError",
    "BatchNotFound",
    "BatchStatus",
    "BatchStatusResponse",
    "BatchTranscriptionRequest",
    "BatchTranscriptionResponse",
    "Language",
    "LettersLanguage",
    "RateLimitError",
    "Status",
    "Timestamp",
    "Transcription",
    "TranscriptionFailed",
    "TranscriptionId",
    "TranscriptionInfo",
    "TranscriptionNotFound",
    "TranscriptionRequest",
    "TranscriptionRequestInfo",
    "TranscriptionSummary",
    "UpdateTimestampsRequest",
]



# This file was auto-generated by Fern from our API Definition.

import typing

Status = typing.Union[
    typing.Literal[
        "RECEIVED", "PENDING", "PROCESSING", "COMPLETED", "CANCELLED", "FAILED", "UPLOADED", "INSUFFICIENT_FUNDS"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .transcription_id import TranscriptionId


class AudioSource(UniversalBaseModel):
    audio_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to a downloadable audio file. Either audio_url or audio_file must be provided, but not both.
    """

    audio_file: typing.Optional[str] = pydantic.Field(default=None)
    """
    Base64 encoded audio file content. Either audio_url or audio_file must be provided, but not both.
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    An optional title for this specific audio file. If a title is not provided, the system will use the batch title followed by "Batch Item i+1". If neither a specific title nor a batch title is available, it will default to "Batch Item i+1". This ensures each audio file has a unique identifier within the batch.
    """

    id: typing.Optional[TranscriptionId] = pydantic.Field(default=None)
    """
    An optional UUID for this specific audio file. If an ID is not provided, the system will generate a UUID for the audio file.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class DurationResponse(UniversalBaseModel):
    duration_seconds: float = pydantic.Field()
    """
    Duration of the audio in seconds. Returns 0 if the duration cannot be determined.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import uuid
import pydantic
import typing


class AddTranscriptionToCategoryRequest(UniversalBaseModel):
    transcription_id: uuid.UUID = pydantic.Field()
    """
    ID of the transcription to add to the category
    """

    position: typing.Optional[int] = pydantic.Field(default=None)
    """
    Optional position within the category for ordering
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from .types.category import Category
from ..core.pydantic_utilities import parse_obj_as
from .errors.category_already_exists import CategoryAlreadyExists
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
import uuid
from ..core.jsonable_encoder import jsonable_encoder
from .errors.category_not_found import CategoryNotFound
from .types.delete_category_response import DeleteCategoryResponse
from .types.add_transcription_to_category_response import AddTranscriptionToCategoryResponse
from .types.remove_transcription_from_category_response import RemoveTranscriptionFromCategoryResponse
from .types.category_transcription import CategoryTranscription
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class CategoriesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_category(
        self,
        *,
        name: str,
        color_hex: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Category:
        """
        Create a new category

        Parameters
        ----------
        name : str
            Name of the category

        color_hex : typing.Optional[str]
            Hex color code for the category (e.g.,

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Category

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.create_category(
            name="name",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/categories/",
            method="POST",
            json={
                "name": name,
                "color_hex": color_hex,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Category,
                    parse_obj_as(
                        type_=Category,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 409:
                raise CategoryAlreadyExists()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def list_categories(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.List[Category]:
        """
        Get all categories for the authenticated user

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Category]

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.list_categories()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/categories/",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[Category],
                    parse_obj_as(
                        type_=typing.List[Category],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_category(
        self, category_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> Category:
        """
        Get a specific category by ID

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Category

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.get_category(
            category_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Category,
                    parse_obj_as(
                        type_=Category,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_category(
        self,
        category_id: uuid.UUID,
        *,
        name: typing.Optional[str] = OMIT,
        color_hex: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Category:
        """
        Update an existing category

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category to update

        name : typing.Optional[str]
            New name for the category

        color_hex : typing.Optional[str]
            New hex color code for the category (e.g.,

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Category

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.update_category(
            category_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}",
            method="PUT",
            json={
                "name": name,
                "color_hex": color_hex,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Category,
                    parse_obj_as(
                        type_=Category,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            if _response.status_code == 409:
                raise CategoryAlreadyExists()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_category(
        self, category_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteCategoryResponse:
        """
        Delete a category (this will also remove all transcription associations)

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category to delete

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteCategoryResponse
            Returns success message

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.delete_category(
            category_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DeleteCategoryResponse,
                    parse_obj_as(
                        type_=DeleteCategoryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def add_transcription_to_category(
        self,
        category_id: uuid.UUID,
        *,
        transcription_id: uuid.UUID,
        position: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddTranscriptionToCategoryResponse:
        """
        Add a transcription to a category

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category

        transcription_id : uuid.UUID
            ID of the transcription to add to the category

        position : typing.Optional[int]
            Optional position within the category for ordering

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddTranscriptionToCategoryResponse
            Returns success message

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.add_transcription_to_category(
            category_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            transcription_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}/transcriptions",
            method="POST",
            json={
                "transcription_id": transcription_id,
                "position": position,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddTranscriptionToCategoryResponse,
                    parse_obj_as(
                        type_=AddTranscriptionToCategoryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def remove_transcription_from_category(
        self,
        category_id: uuid.UUID,
        transcription_id: uuid.UUID,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> RemoveTranscriptionFromCategoryResponse:
        """
        Remove a transcription from a category

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category

        transcription_id : uuid.UUID
            ID of the transcription to remove

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        RemoveTranscriptionFromCategoryResponse
            Returns success message

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.remove_transcription_from_category(
            category_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            transcription_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}/transcriptions/{jsonable_encoder(transcription_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    RemoveTranscriptionFromCategoryResponse,
                    parse_obj_as(
                        type_=RemoveTranscriptionFromCategoryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_transcription_categories(
        self, transcription_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[Category]:
        """
        Get all categories for a specific transcription

        Parameters
        ----------
        transcription_id : uuid.UUID
            ID of the transcription

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Category]

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.get_transcription_categories(
            transcription_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/categories/by-transcription/{jsonable_encoder(transcription_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[Category],
                    parse_obj_as(
                        type_=typing.List[Category],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_category_transcriptions(
        self, category_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[CategoryTranscription]:
        """
        Get all transcriptions in a specific category

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[CategoryTranscription]

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.categories.get_category_transcriptions(
            category_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}/transcriptions",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[CategoryTranscription],
                    parse_obj_as(
                        type_=typing.List[CategoryTranscription],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncCategoriesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_category(
        self,
        *,
        name: str,
        color_hex: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Category:
        """
        Create a new category

        Parameters
        ----------
        name : str
            Name of the category

        color_hex : typing.Optional[str]
            Hex color code for the category (e.g.,

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Category

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.create_category(
                name="name",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/categories/",
            method="POST",
            json={
                "name": name,
                "color_hex": color_hex,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Category,
                    parse_obj_as(
                        type_=Category,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 409:
                raise CategoryAlreadyExists()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def list_categories(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[Category]:
        """
        Get all categories for the authenticated user

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Category]

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.list_categories()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/categories/",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[Category],
                    parse_obj_as(
                        type_=typing.List[Category],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_category(
        self, category_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> Category:
        """
        Get a specific category by ID

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Category

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.get_category(
                category_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Category,
                    parse_obj_as(
                        type_=Category,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_category(
        self,
        category_id: uuid.UUID,
        *,
        name: typing.Optional[str] = OMIT,
        color_hex: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Category:
        """
        Update an existing category

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category to update

        name : typing.Optional[str]
            New name for the category

        color_hex : typing.Optional[str]
            New hex color code for the category (e.g.,

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Category

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.update_category(
                category_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}",
            method="PUT",
            json={
                "name": name,
                "color_hex": color_hex,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Category,
                    parse_obj_as(
                        type_=Category,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            if _response.status_code == 409:
                raise CategoryAlreadyExists()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_category(
        self, category_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteCategoryResponse:
        """
        Delete a category (this will also remove all transcription associations)

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category to delete

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteCategoryResponse
            Returns success message

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.delete_category(
                category_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DeleteCategoryResponse,
                    parse_obj_as(
                        type_=DeleteCategoryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def add_transcription_to_category(
        self,
        category_id: uuid.UUID,
        *,
        transcription_id: uuid.UUID,
        position: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddTranscriptionToCategoryResponse:
        """
        Add a transcription to a category

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category

        transcription_id : uuid.UUID
            ID of the transcription to add to the category

        position : typing.Optional[int]
            Optional position within the category for ordering

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddTranscriptionToCategoryResponse
            Returns success message

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.add_transcription_to_category(
                category_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                transcription_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}/transcriptions",
            method="POST",
            json={
                "transcription_id": transcription_id,
                "position": position,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddTranscriptionToCategoryResponse,
                    parse_obj_as(
                        type_=AddTranscriptionToCategoryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def remove_transcription_from_category(
        self,
        category_id: uuid.UUID,
        transcription_id: uuid.UUID,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> RemoveTranscriptionFromCategoryResponse:
        """
        Remove a transcription from a category

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category

        transcription_id : uuid.UUID
            ID of the transcription to remove

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        RemoveTranscriptionFromCategoryResponse
            Returns success message

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.remove_transcription_from_category(
                category_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                transcription_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}/transcriptions/{jsonable_encoder(transcription_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    RemoveTranscriptionFromCategoryResponse,
                    parse_obj_as(
                        type_=RemoveTranscriptionFromCategoryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_transcription_categories(
        self, transcription_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[Category]:
        """
        Get all categories for a specific transcription

        Parameters
        ----------
        transcription_id : uuid.UUID
            ID of the transcription

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Category]

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.get_transcription_categories(
                transcription_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/categories/by-transcription/{jsonable_encoder(transcription_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[Category],
                    parse_obj_as(
                        type_=typing.List[Category],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_category_transcriptions(
        self, category_id: uuid.UUID, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[CategoryTranscription]:
        """
        Get all transcriptions in a specific category

        Parameters
        ----------
        category_id : uuid.UUID
            ID of the category

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[CategoryTranscription]

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.categories.get_category_transcriptions(
                category_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/categories/{jsonable_encoder(category_id)}/transcriptions",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[CategoryTranscription],
                    parse_obj_as(
                        type_=typing.List[CategoryTranscription],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise CategoryNotFound()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from .types import LinkRequest, LinkResponse, Site
from .errors import LinkError, LinkNotFound, LinkNotSupported

__all__ = ["LinkError", "LinkNotFound", "LinkNotSupported", "LinkRequest", "LinkResponse", "Site"]



# This file was auto-generated by Fern from our API Definition.

from .category_already_exists import CategoryAlreadyExists
from .category_not_found import CategoryNotFound

__all__ = ["CategoryAlreadyExists", "CategoryNotFound"]



# This file was auto-generated by Fern from our API Definition.

from .authentication_error import AuthenticationError
from .batch_not_found import BatchNotFound
from .rate_limit_error import RateLimitError
from .transcription_failed import TranscriptionFailed
from .transcription_not_found import TranscriptionNotFound

__all__ = ["AuthenticationError", "BatchNotFound", "RateLimitError", "TranscriptionFailed", "TranscriptionNotFound"]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class CreateCategoryRequest(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Name of the category
    """

    color_hex: typing.Optional[str] = pydantic.Field(default=None)
    """
    Hex color code for the category (e.g.,
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..transcribe.types.transcription_id import TranscriptionId
from ..core.request_options import RequestOptions
from .types.outline_topic import OutlineTopic
from ..core.pydantic_utilities import parse_obj_as
from ..transcribe.errors.authentication_error import AuthenticationError
from ..transcribe.errors.rate_limit_error import RateLimitError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TimestampsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def outline(
        self,
        *,
        transcription_id: TranscriptionId,
        monotone: typing.Optional[bool] = OMIT,
        conclusion_bias: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[OutlineTopic]:
        """
        Outline of topics discussed by timestamp, generated end-to-end from a transcription ID.

        This endpoint will:
        1) Fetch the transcript and word-level timestamps for the given transcription
        2) Generate chapter topics (title + starting_phrase) using an LLM from the transcript text
        3) Align each topic's starting phrase to timestamps

        Parameters
        ----------
        transcription_id : TranscriptionId
            ID of the transcription to process end-to-end

        monotone : typing.Optional[bool]
            If true, each topic is searched after the previous topic's start (with a small backoff)

        conclusion_bias : typing.Optional[bool]
            If true and a title includes the word "conclusion", search in the last third of the audio

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[OutlineTopic]

        Examples
        --------
        import uuid

        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.timestamps.outline(
            transcription_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/timestamps/outline",
            method="POST",
            json={
                "transcription_id": transcription_id,
                "monotone": monotone,
                "conclusion_bias": conclusion_bias,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[OutlineTopic],
                    parse_obj_as(
                        type_=typing.List[OutlineTopic],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncTimestampsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def outline(
        self,
        *,
        transcription_id: TranscriptionId,
        monotone: typing.Optional[bool] = OMIT,
        conclusion_bias: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[OutlineTopic]:
        """
        Outline of topics discussed by timestamp, generated end-to-end from a transcription ID.

        This endpoint will:
        1) Fetch the transcript and word-level timestamps for the given transcription
        2) Generate chapter topics (title + starting_phrase) using an LLM from the transcript text
        3) Align each topic's starting phrase to timestamps

        Parameters
        ----------
        transcription_id : TranscriptionId
            ID of the transcription to process end-to-end

        monotone : typing.Optional[bool]
            If true, each topic is searched after the previous topic's start (with a small backoff)

        conclusion_bias : typing.Optional[bool]
            If true and a title includes the word "conclusion", search in the last third of the audio

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[OutlineTopic]

        Examples
        --------
        import asyncio
        import uuid

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.timestamps.outline(
                transcription_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/timestamps/outline",
            method="POST",
            json={
                "transcription_id": transcription_id,
                "monotone": monotone,
                "conclusion_bias": conclusion_bias,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[OutlineTopic],
                    parse_obj_as(
                        type_=typing.List[OutlineTopic],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class Balance(UniversalBaseModel):
    total_balance: int = pydantic.Field()
    """
    The total balance in the account, not subtracting pending charges, represented in cents.
    """

    available_balance: int = pydantic.Field()
    """
    The available balance after accounting for pending charges, represented in cents. This is the amount that can be used for new transcriptions.
    """

    pending_balance: int = pydantic.Field()
    """
    The amount of pending charges from transcriptions that are in progress or queued, represented in cents.
    """

    all_time_deposits: int = pydantic.Field()
    """
    The total amount ever deposited into the account, represented in cents.
    """

    all_time_spend: int = pydantic.Field()
    """
    The total amount ever spent on completed transcriptions, represented in cents.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from .types.duration_response import DurationResponse
from ..core.pydantic_utilities import parse_obj_as
from ..transcribe.errors.authentication_error import AuthenticationError
from ..transcribe.errors.rate_limit_error import RateLimitError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class UtilsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_duration(
        self,
        *,
        audio_url: typing.Optional[str] = OMIT,
        audio_file: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DurationResponse:
        """
        Returns the audio duration in seconds for a provided URL or base64-encoded file.

        Provide either `audio_url` or `audio_file` (base64). If both are provided, the request is invalid.

        Parameters
        ----------
        audio_url : typing.Optional[str]
            Direct URL to a downloadable audio file.

        audio_file : typing.Optional[str]
            Base64-encoded audio file content. Do not include a data URI prefix.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DurationResponse

        Examples
        --------
        from soferai import SoferAI

        client = SoferAI(
            api_key="YOUR_API_KEY",
        )
        client.utils.get_duration()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/utils/duration",
            method="POST",
            json={
                "audio_url": audio_url,
                "audio_file": audio_file,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DurationResponse,
                    parse_obj_as(
                        type_=DurationResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncUtilsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_duration(
        self,
        *,
        audio_url: typing.Optional[str] = OMIT,
        audio_file: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DurationResponse:
        """
        Returns the audio duration in seconds for a provided URL or base64-encoded file.

        Provide either `audio_url` or `audio_file` (base64). If both are provided, the request is invalid.

        Parameters
        ----------
        audio_url : typing.Optional[str]
            Direct URL to a downloadable audio file.

        audio_file : typing.Optional[str]
            Base64-encoded audio file content. Do not include a data URI prefix.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DurationResponse

        Examples
        --------
        import asyncio

        from soferai import AsyncSoferAI

        client = AsyncSoferAI(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.utils.get_duration()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/utils/duration",
            method="POST",
            json={
                "audio_url": audio_url,
                "audio_file": audio_file,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DurationResponse,
                    parse_obj_as(
                        type_=DurationResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 401:
                raise AuthenticationError()
            if _response.status_code == 429:
                raise RateLimitError()
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .audio_source import AudioSource
import pydantic
from .transcription_request_info import TranscriptionRequestInfo
import uuid


class BatchTranscriptionRequest(UniversalBaseModel):
    audio_sources: typing.List[AudioSource] = pydantic.Field()
    """
    List of audio sources to transcribe with the same settings. Each item should have either audio_url or audio_file.
    """

    info: TranscriptionRequestInfo = pydantic.Field()
    """
    Shared transcription parameters for all audio files in the batch
    """

    batch_title: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional title for the batch. The system will first check for a title in the Audio Source itself. If no title is provided there, it defaults to batch title providded here with "- Batch Item N" appended.
    """

    batch_id: typing.Optional[uuid.UUID] = pydantic.Field(default=None)
    """
    Optional ID for the batch. If not provided, a UUID will be generated.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2



# This file was auto-generated by Fern from our API Definition.

from .types import (
    AddTranscriptionToCategoryRequest,
    AddTranscriptionToCategoryResponse,
    Category,
    CategoryTranscription,
    CreateCategoryRequest,
    DeleteCategoryResponse,
    RemoveTranscriptionFromCategoryResponse,
    UpdateCategoryRequest,
)
from .errors import CategoryAlreadyExists, CategoryNotFound

__all__ = [
    "AddTranscriptionToCategoryRequest",
    "AddTranscriptionToCategoryResponse",
    "Category",
    "CategoryAlreadyExists",
    "CategoryNotFound",
    "CategoryTranscription",
    "CreateCategoryRequest",
    "DeleteCategoryResponse",
    "RemoveTranscriptionFromCategoryResponse",
    "UpdateCategoryRequest",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import uuid
import pydantic
import typing


class CategoryTranscription(UniversalBaseModel):
    id: uuid.UUID = pydantic.Field()
    """
    ID of the transcription
    """

    title: str = pydantic.Field()
    """
    Title of the transcription
    """

    status: str = pydantic.Field()
    """
    Current status of the transcription
    """

    position: typing.Optional[int] = pydantic.Field(default=None)
    """
    Position of this transcription within the category
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
